@@ -1172,7 +1172,6 @@ def PlotInteraction(interactions, **kwargs):
     plt.xticks(fontsize = fontsize*0.8)
     plt.xlabel("Time (s)",fontsize=fontsize)
     plt.ylim([barHeight,barHeight])
-    plt.title(figureTitle,fontsize=fontsize)
     plt.show()
     if type(saveName) != type(None):
         plt.savefig(saveName+figformat)
@@ -1187,5 +1186,5 @@ def PlotInteraction(interactions, **kwargs):
     ax.tick_params(axis='y', labelsize=fontsize*.8)
     ax.legend(ncol=int(interactions.obj.max()),fontsize=fontsize*.8)
     ax.set_xlabel('Time (s)',fontsize=fontsize)
-    ax.set_title(figureTitle,fontsize=fontsize)
+
     ax.set_ylim([-barHeight,barHeight])
